==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMLatencySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JVMLatencySpecFluent<A extends JVMLatencySpecFluent<A>> extends BaseFluent<A>{
  public JVMLatencySpecFluent() {
  }
  public JVMLatencySpecFluent(JVMLatencySpec instance) {
    instance = (instance != null ? instance : new JVMLatencySpec());

    if (instance != null) {
      this.withClassName(instance.getClassName());
      this.withLatency(instance.getLatency());
      this.withMethod(instance.getMethod());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
      this.withClassName(instance.getClassName());
      this.withLatency(instance.getLatency());
      this.withMethod(instance.getMethod());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
    }
  }
  private String className;
  private Integer latency;
  private String method;
  private Integer pid;
  private Integer port;
  public String getClassName() {
    return this.className;
  }
  public A withClassName(String className) {
    this.className=className; return (A) this;
  }
  public boolean hasClassName() {
    return this.className != null;
  }
  public Integer getLatency() {
    return this.latency;
  }
  public A withLatency(Integer latency) {
    this.latency=latency; return (A) this;
  }
  public boolean hasLatency() {
    return this.latency != null;
  }
  public String getMethod() {
    return this.method;
  }
  public A withMethod(String method) {
    this.method=method; return (A) this;
  }
  public boolean hasMethod() {
    return this.method != null;
  }
  public Integer getPid() {
    return this.pid;
  }
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  public boolean hasPid() {
    return this.pid != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public boolean hasPort() {
    return this.port != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMLatencySpecFluent that = (JVMLatencySpecFluent) o;
    if (!java.util.Objects.equals(className, that.className)) return false;

    if (!java.util.Objects.equals(latency, that.latency)) return false;

    if (!java.util.Objects.equals(method, that.method)) return false;

    if (!java.util.Objects.equals(pid, that.pid)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(className,  latency,  method,  pid,  port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMLatencySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class JVMLatencySpecFluent<A extends JVMLatencySpecFluent<A>> extends BaseFluent<A>{
  public JVMLatencySpecFluent() {
  }
  
  public JVMLatencySpecFluent(JVMLatencySpec instance) {
    this.copyInstance(instance);
  }
  private String className;
  private Integer latency;
  private String method;
  private Integer pid;
  private Integer port;
  
  protected void copyInstance(JVMLatencySpec instance) {
    instance = (instance != null ? instance : new JVMLatencySpec());
  
    if (instance != null) {
        this.withClassName(instance.getClassName());
        this.withLatency(instance.getLatency());
        this.withMethod(instance.getMethod());
        this.withPid(instance.getPid());
        this.withPort(instance.getPort());
        this.withClassName(instance.getClassName());
        this.withLatency(instance.getLatency());
        this.withMethod(instance.getMethod());
        this.withPid(instance.getPid());
        this.withPort(instance.getPort());
      }
  }
  
  public String getClassName() {
    return this.className;
  }
  
  public A withClassName(String className) {
    this.className=className; return (A) this;
  }
  
  public boolean hasClassName() {
    return this.className != null;
  }
  
  public Integer getLatency() {
    return this.latency;
  }
  
  public A withLatency(Integer latency) {
    this.latency=latency; return (A) this;
  }
  
  public boolean hasLatency() {
    return this.latency != null;
  }
  
  public String getMethod() {
    return this.method;
  }
  
  public A withMethod(String method) {
    this.method=method; return (A) this;
  }
  
  public boolean hasMethod() {
    return this.method != null;
  }
  
  public Integer getPid() {
    return this.pid;
  }
  
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  
  public boolean hasPid() {
    return this.pid != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMLatencySpecFluent that = (JVMLatencySpecFluent) o;
    if (!java.util.Objects.equals(className, that.className)) return false;
  
    if (!java.util.Objects.equals(latency, that.latency)) return false;
  
    if (!java.util.Objects.equals(method, that.method)) return false;
  
    if (!java.util.Objects.equals(pid, that.pid)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(className,  latency,  method,  pid,  port,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (className != null) { sb.append("className:"); sb.append(className + ","); }
    if (latency != null) { sb.append("latency:"); sb.append(latency + ","); }
    if (method != null) { sb.append("method:"); sb.append(method + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  

}
